@@ -1,4 +1,4 @@
-"""Adapted for python from the KDToolBox
+"""Adapted for python from the KDToolBox.
 
 https://github.com/KDAB/KDToolBox/tree/master/qt/KDSignalThrottler
 
@@ -94,10 +94,10 @@ class GenericSignalThrottler(QObject):
 
     def timeout(self) -> int:
         """Return current timeout in milliseconds."""
-        return self._timer.interval()  # type: ignore
+        return self._timer.interval()
 
     def setTimeout(self, timeout: int) -> None:
-        """Set timeout in milliseconds"""
+        """Set timeout in milliseconds."""
         if self._timer.interval() != timeout:
             self._timer.setInterval(timeout)
             self.timeoutChanged.emit(timeout)
@@ -230,7 +230,7 @@ def qthrottled(
 
 @overload
 def qthrottled(
-    func: "Literal[None]" = None,
+    func: Optional["Literal[None]"] = None,
     timeout: int = 100,
     leading: bool = True,
     timer_type: Qt.TimerType = Qt.TimerType.PreciseTimer,
@@ -289,7 +289,7 @@ def qdebounced(
 
 @overload
 def qdebounced(
-    func: "Literal[None]" = None,
+    func: Optional["Literal[None]"] = None,
     timeout: int = 100,
     leading: bool = False,
     timer_type: Qt.TimerType = Qt.TimerType.PreciseTimer,
@@ -371,10 +371,10 @@ def _make_decorator(
             throttle.throttle()
             return future
 
-        setattr(inner, "cancel", throttle.cancel)  # noqa
-        setattr(inner, "flush", throttle.flush)  # noqa
-        setattr(inner, "set_timeout", throttle.setTimeout)  # noqa
-        setattr(inner, "triggered", throttle.triggered)  # noqa
+        inner.cancel = throttle.cancel
+        inner.flush = throttle.flush
+        inner.set_timeout = throttle.setTimeout
+        inner.triggered = throttle.triggered
         return inner  # type: ignore
 
     return deco(func) if func is not None else deco
